@@ -28,17 +28,10 @@
 #include <ctype.h>
 #include <time.h>
 #include <string.h>
-#if VARNISHAPI_MAJOR > 5
-# include "cache/cache.h"
-# include "vcl.h"
-# include "vcc_if.h"
-#else
-# include "vcl.h"
-# include "vrt.h"
-# include "vcc_if.h"
-# include "cache/cache.h"
-#endif
-#define WSPTR(s) ((s)->ws)
+
+#include <cache/cache.h>
+#include <vcl.h>
+#include <vcc_if.h>
 
 #ifdef VPFX
 # define VEVENT(a) VPFX(a)
@@ -454,16 +447,16 @@ mkfilename(VRT_CTX, struct binlog_config *conf)
 
 	if (conf->flags & BLF_ROUNDTS)
 		ts -= ts % conf->interval;
-	u = WS_Reserve(WSPTR(ctx), 0);
-        p = WSPTR(ctx)->f;
+	u = WS_ReserveAll(ctx->ws);
+        p = ctx->ws->f;
         n = strftime(p, u, conf->pattern, gmtime(&ts));
 	if (n == 0) {
-		WS_Release(WSPTR(ctx), 0);
+		WS_Release(ctx->ws, 0);
 		return NULL;
 	}
 	q = strdup(p);
 	AN(q);
-	WS_Release(WSPTR(ctx), 0);
+	WS_Release(ctx->ws, 0);
 	return q;
 }
 
